Mixed logistic regression for GWAS, using dosages
association.test.logistic.dosage(
filename,
Y,
X,
K,
beg,
end,
algorithm = c("amle", "offset"),
eigenK,
p = 0,
n.cores = 1L,
...
)A data frame giving for each SNP the association statistics.
Name of a dosage file
phenotype vector. Default is column pheno of x@ped
A matrix of covariates (defaults to a column of ones for the intercept)
A genetic relationship matrix (or a list of such matrices)
Index of the first SNP tested for association
Index of the last SNP tested for association
Algorithm to use
eigen decomposition of K (only if p > 0)
Number of principal components to include in the model
number of cores to use
Additional parameter for gaston::logistic.mm.aireml
Dosage files can be VCF files with 'DS' or 'GP' fields. It is also possible to use a file with columns 'id"', 'chr', 'pos', 'A1', 'A2', 'sample1', 'sample2', etc. These files should have a header with column names.
For more details refer to association.test.logistic and association.test.
association.test.logistic, association.test